@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 # archived.pl - This script does the web archives building for Sympa
-# RCS Identication ; $Revision: 6702 $ ; $Date: 2010-10-01 16:02:48 +0200 (ven 01 oct 2010) $ 
+# RCS Identication ; $Revision: 7965 $ ; $Date: 2012-11-19 10:41:47 +0100 (lun 19 nov 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -267,12 +267,11 @@ while (!$end) {
 		        do_log('err',"unable to load new message $arcpath/arctxt/$message");
 			next;
 		   }
-		   my $messagesender = $new_message->{'sender'};
-		   lc($messagesender);
+		   my $messagesender = lc($new_message->{'sender'});
 
-		   unless ($sender == $messagesender) {
+		   unless ($sender eq $messagesender) {
 		       &do_log('err', 'remove command by unauthorized sender');
-		       return undef;
+		       next;
 		   }
 	       }
 	       # this point : requested command is from a authorized personn (message sender or list admin or listmaster
@@ -372,6 +371,8 @@ while (!$end) {
 	   }
        }
    }
+    ## Free zombie sendmail processes
+    &mail::reaper;
 }
 do_log('notice', 'archived exited normally due to signal');
 &tools::remove_pid($wwsconf->{'archived_pidfile'}, $$);
