@@ -2,7 +2,7 @@
 
 # bounced.pl - This script runs as a daemon ; it does the incoming 
 # non-delivery reports analysis and storage
-# RCS Identication ; $Revision: 7119 $ ; $Date: 2011-06-16 05:05:30 +0200 (jeu 16 jun 2011) $ 
+# RCS Identication ; $Revision: 7451 $ ; $Date: 2012-07-06 11:21:24 +0200 (ven 06 jui 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -330,7 +330,8 @@ while (!$end) {
 	    my $user_agent;
 	    my $version;
 	    my $feedback_type = '';
-	    my $listname, $robot;
+	    my $listname;
+	    my $robot;
 	    foreach my $p (@parts) {
 		my $h = $p->head();
 		my $content = $h->get('Content-type');
@@ -518,7 +519,7 @@ while (!$end) {
 	    unless ($adr_count) {
 		
 		if ( $who ) {	# rcpt not recognized in the bounce but VERP was used
-		    &store_bounce ($bounce_dir,$file,$who)
+		    &store_bounce($bounce_dir, $file, $who);
 		    &update_subscriber_bounce_history($list, 'unknown', $who); # status is undefined 
 		}else{          # no VERP and no rcpt recognized		
 		    my $escaped_from = &tools::escape_chars($from);
