@@ -1,5 +1,5 @@
 # admin.pm - This module includes administrative function for the lists
-# RCS Identication ; $Revision: 7122 $ ; $Date: 2011-06-18 04:17:17 +0200 (sam 18 jun 2011) $ 
+# RCS Identication ; $Revision: 7603 $ ; $Date: 2012-09-15 15:41:53 +0200 (sam 15 sep 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -41,6 +41,7 @@ use Language;
 use Log;
 use tools;
 use Sympa::Constants;
+use Data::Dumper;
 
 =pod 
 
@@ -148,6 +149,7 @@ Creates a list. Used by the create_list() sub in sympa.pl and the do_create_list
 #       - $template : the create list template 
 #       - $robot : the list's robot       
 #       - $origin : the source of the command : web, soap or command_line  
+#              no longer used
 # OUT : - hash with keys :
 #          -list :$list
 #          -aliases : undef if not applicable; 1 (if ok) or
@@ -200,19 +202,23 @@ sub create_list_old{
 	}
     }    
 
+    if ($param->{'listname'} eq &Conf::get_robot_conf($robot,'email')) {
+	&do_log('err','admin::create_list : incorrect listname %s matches one of service aliases', $param->{'listname'});
+	return undef;
+    }
+
     ## Check listname on SMTP server
-    my $res = &list_check_smtp($param->{'listname'});
+    my $res = &list_check_smtp($param->{'listname'}, $robot);
     unless (defined $res) {
-	&do_log('err', "admin::create_list_old : can't check list %.128s on %.128s",
-		$param->{'listname'},
-		$Conf::Conf{'list_check_smtp'});
+	&do_log('err', "admin::create_list_old : can't check list %.128s on %s",
+		$param->{'listname'}, $robot);
 	return undef;
     }
     
     ## Check this listname doesn't exist already.
     if( $res || new List ($param->{'listname'}, $robot, {'just_try' => 1})) {
-	&do_log('err', 'admin::create_list_old : could not create already existing list %s for ', 
-		$param->{'listname'});
+	&do_log('err', 'admin::create_list_old : could not create already existing list %s on %s for ', 
+		$param->{'listname'}, $robot);
 	foreach my $o (@{$param->{'owner'}}){
 	    &do_log('err',$o->{'email'});
 	}
@@ -275,11 +281,10 @@ sub create_list_old{
     unless ($lock->lock('write')) {
 	return undef;
     }
-    if($origin eq "command_line") {
-	open CONFIG, '>:utf8', "$list_dir/config";
-    }
-    else {
-	open CONFIG, '>:bytes', "$list_dir/config";
+    unless (open CONFIG, '>', "$list_dir/config") {
+	&do_log('err','Impossible to create %s/config : %s', $list_dir, $!);
+	$lock->unlock();
+	return undef;
     }
     ## Use an intermediate handler to encode to filesystem_encoding
     my $config = '';
@@ -295,18 +300,11 @@ sub create_list_old{
 
     ## Creation of the info file 
     # remove DOS linefeeds (^M) that cause problems with Outlook 98, AOL, and EIMS:
-    $param->{'description'} =~ s/\015//g;
+    $param->{'description'} =~ s/\r\n|\r/\n/g;
 
-    ## info file creation. Use UTF-8 for command line orgigin only.
-    if($origin eq "command_line") {
-	unless (open INFO, '>:utf8', "$list_dir/info") {
-	    &do_log('err','Impossible to create %s/info : %s',$list_dir,$!);
-	}
-    }
-    else {
-	unless (open INFO, '>:bytes', "$list_dir/info") {
-	    &do_log('err','Impossible to create %s/info : %s',$list_dir,$!);
-	}
+    ## info file creation.
+    unless (open INFO, '>', "$list_dir/info") {
+	&do_log('err','Impossible to create %s/info : %s', $list_dir, $!);
     }
     if (defined $param->{'description'}) {
 	Encode::from_to($param->{'description'}, 'utf8', $Conf::Conf{'filesystem_encoding'});
@@ -329,18 +327,19 @@ sub create_list_old{
     my $return = {};
     $return->{'list'} = $list;
 
-    if ($param->{'status'} eq 'open') {
+    if ($list->{'admin'}{'status'} eq 'open') {
 	$return->{'aliases'} = &install_aliases($list,$robot);
-	return $return;
-    }
-
+    }else{
     $return->{'aliases'} = 1;
+    }
 
     ## Synchronize list members if required
     if ($list->has_include_data_sources()) {
 	&do_log('notice', "Synchronizing list members...");
 	$list->sync_include();
-    }   
+    }
+    
+    $list->save_config;
 
     return $return;
 }
@@ -409,18 +408,21 @@ sub create_list{
 	    return undef;
 	}
     }    
+    if ($param->{'listname'} eq &Conf::get_robot_conf($robot,'email')) {
+	&do_log('err','admin::create_list : incorrect listname %s matches one of service aliases', $param->{'listname'});
+	return undef;
+    }
 
     ## Check listname on SMTP server
-    my $res = &list_check_smtp($param->{'listname'});
+    my $res = &list_check_smtp($param->{'listname'}, $robot);
     unless (defined $res) {
-	&do_log('err', "admin::create_list : can't check list %.128s on %.128s",
-		$param->{'listname'},
-		$Conf::Conf{'list_check_smtp'});
+	&do_log('err', "admin::create_list : can't check list %.128s on %s",
+		$param->{'listname'}, $robot);
 	return undef;
     }
 
     if ($res) {
-	&do_log('err', 'admin::create_list : could not create already existing list %s for ',$param->{'listname'});
+	&do_log('err', 'admin::create_list : could not create already existing list %s on %s for ', $param->{'listname'}, $robot);
 	foreach my $o (@{$param->{'owner'}}){
 	    &do_log('err',$o->{'email'});
 	}
@@ -434,6 +436,8 @@ sub create_list{
 	return undef;
     }
 
+    my $family_config = &Conf::get_robot_conf($robot,'automatic_list_families');
+    $param->{'family_config'} = $family_config->{$family->{'name'}};
     my $conf;
     my $tt_result = &tt2::parse_tt2($param, 'config.tt2', \$conf, [$family->{'dir'}]);
     unless (defined $tt_result || !$abort_on_error) {
@@ -441,7 +445,7 @@ sub create_list{
                 $param->{'listname'}, $family->{'name'},$robot);
       return undef;
     }
-
+    
      ## Create the list directory
      my $list_dir;
 
@@ -481,7 +485,11 @@ sub create_list{
     }
 
     ## Creation of the config file
-    open CONFIG, '>:utf8', "$list_dir/config";
+    unless (open CONFIG, '>', "$list_dir/config") {
+	&do_log('err','Impossible to create %s/config : %s', $list_dir, $!);
+	$lock->unlock();
+	return undef;
+    }
     #&tt2::parse_tt2($param, 'config.tt2', \*CONFIG, [$family->{'dir'}]);
     print CONFIG $conf;
     close CONFIG;
@@ -491,16 +499,34 @@ sub create_list{
 
     ## Creation of the info file 
     # remove DOS linefeeds (^M) that cause problems with Outlook 98, AOL, and EIMS:
-    $param->{'description'} =~ s/\015//g;
+    $param->{'description'} =~ s/\r\n|\r/\n/g;
     
-    unless (open INFO, '>:utf8', "$list_dir/info") {
-	&do_log('err','Impossible to create %s/info : %s',$list_dir,$!);
+    unless (open INFO, '>', "$list_dir/info") {
+	&do_log('err','Impossible to create %s/info : %s', $list_dir, $!);
     }
     if (defined $param->{'description'}) {
 	print INFO $param->{'description'};
     }
     close INFO;
-    
+
+    ## Create associated files if a template was given.
+    for my $file ('message.footer','message.header','message.footer.mime','message.header.mime','info') {
+	my $template_file = &tools::get_filename('etc',{},$file.".tt2", $robot,$family);
+	if (defined $template_file) {
+	    my $file_content;
+	    my $tt_result = &tt2::parse_tt2($param, $file.".tt2", \$file_content, [$family->{'dir'}]);
+	    unless (defined $tt_result) {
+		&do_log('err', 'admin::create_list : tt2 error. List %s from family %s@%s, file %s',
+			$param->{'listname'}, $family->{'name'},$robot,$file);
+	    }
+	    unless (open FILE, '>', "$list_dir/$file") {
+		&do_log('err','Impossible to create %s/%s : %s',$list_dir,$file,$!);
+	    }
+	    print FILE $file_content;
+	    close FILE;
+	}
+    }
+
     ## Create list object
     my $list;
     unless ($list = new List ($param->{'listname'}, $robot)) {
@@ -533,10 +559,9 @@ sub create_list{
 
     if ($list->{'admin'}{'status'} eq 'open') {
 	$return->{'aliases'} = &install_aliases($list,$robot);
-	return $return;
-    }
-
+    }else{
     $return->{'aliases'} = 1;
+    }
 
     ## Synchronize list members if required
     if ($list->has_include_data_sources()) {
@@ -605,7 +630,11 @@ sub update_list{
     }
 
     ## Creation of the config file
-    open CONFIG, '>:utf8', "$list->{'dir'}/config";
+    unless (open CONFIG, '>', "$list->{'dir'}/config") {
+	&do_log('err','Impossible to create %s/config : %s', $list->{'dir'}, $!);
+	$lock->unlock();
+	return undef;
+    }
     &tt2::parse_tt2($param, 'config.tt2', \*CONFIG, [$family->{'dir'}]);
     close CONFIG;
 
@@ -708,14 +737,15 @@ sub rename_list{
     ## Check listname on SMTP server
     my $res = list_check_smtp($param{'new_listname'}, $param{'new_robot'});
     unless ( defined($res) ) {
-      &do_log('err', "can't check list %.128s on %.128s", $param{'new_listname'}, &Conf::get_robot_conf($param{'new_robot'}, 'list_check_smtp'));
+      &do_log('err', "can't check list %.128s on %.128s",
+	      $param{'new_listname'}, $param{'new_robot'});
       return 'internal';
     }
 
     if( $res || 
 	($list->{'name'} ne $param{'new_listname'}) && ## Do not test if listname did not change
 	(new List ($param{'new_listname'}, $param{'new_robot'}, {'just_try' => 1}))) {
-      &do_log('err', 'Could not rename list %s : new list %s already existing list', $list->{'name'}, $param{'new_listname'});
+      &do_log('err', 'Could not rename list %s on %s: new list %s on %s already existing list', $list->{'name'}, $robot, $param{'new_listname'}, $param{'new_robot'});
       return 'list_already_exists';
     }
     
@@ -801,9 +831,8 @@ sub rename_list{
 	 }
 	 
 	 # if subscribtion are stored in database rewrite the database
-	 if ($list->{'admin'}{'user_data_source'} =~ /^(database|include2)$/) {
-	     &List::rename_list_db ($list,$param{'new_listname'},$param{'new_robot'});
-	 }
+	 &List::rename_list_db($list, $param{'new_listname'},
+			       $param{'new_robot'});
      }
      ## Install new aliases
      $param{'listname'} = $param{'new_listname'};
@@ -835,10 +864,11 @@ sub rename_list{
 		 &do_log('err', "Unable to open '%s' spool : %s", $Conf::Conf{$spool}, $!);
 	     }
 	     
-	     foreach my $file (sort grep (!/^\.+$/,readdir(DIR))) {
+	     foreach my $file (sort readdir(DIR)) {
 		 next unless ($file =~ /^$old_listname\_/ ||
 			      $file =~ /^$old_listname\./ ||
 			      $file =~ /^$old_listname\@$robot\./ ||
+			      $file =~ /^\.$old_listname\@$robot\_/ ||
 			      $file =~ /^$old_listname\@$robot\_/ ||
 			      $file =~ /\.$old_listname$/);
 		 
@@ -851,6 +881,8 @@ sub rename_list{
 		     $newfile =~ s/^$old_listname\@$robot\./$param{'new_listname'}\@$param{'new_robot'}\./;
 		 }elsif ($file =~ /^$old_listname\@$robot\_/) {
 		     $newfile =~ s/^$old_listname\@$robot\_/$param{'new_listname'}\@$param{'new_robot'}\_/;
+		 }elsif ($file =~ /^\.$old_listname\@$robot\_/) {
+		     $newfile =~ s/^\.$old_listname\@$robot\_/\.$param{'new_listname'}\@$param{'new_robot'}\_/;
 		 }elsif ($file =~ /\.$old_listname$/) {
 		     $newfile =~ s/\.$old_listname$/\.$param{'new_listname'}/;
 		 }
@@ -1082,12 +1114,14 @@ sub check_owner_defined {
      my $smtp;
      my (@suf, @addresses);
 
-     my $smtp_relay = $Conf::Conf{'robots'}{$robot}{'list_check_smtp'} || $Conf::Conf{'list_check_smtp'};
-     my $suffixes = $Conf::Conf{'robots'}{$robot}{'list_check_suffixes'} || $Conf::Conf{'list_check_suffixes'};
+     my $smtp_relay = &Conf::get_robot_conf($robot, 'list_check_smtp');
+     my $smtp_helo = &Conf::get_robot_conf($robot, 'list_check_helo') || $smtp_relay;
+     $smtp_helo =~ s/:[-\w]+$//;
+     my $suffixes = &Conf::get_robot_conf($robot, 'list_check_suffixes');
      return 0 
 	 unless ($smtp_relay && $suffixes);
      my $domain = &Conf::get_robot_conf($robot, 'host');
-     &do_log('debug2', 'list_check_smtp(%s)',$list);
+     &do_log('debug2', 'list_check_smtp(%s,%s)', $list, $robot);
      @suf = split(/,/,$suffixes);
      return 0 if ! @suf;
      for(@suf) {
@@ -1100,7 +1134,7 @@ sub check_owner_defined {
 	 return undef;
      }
      if( $smtp = Net::SMTP->new($smtp_relay,
-				Hello => $smtp_relay,
+				Hello => $smtp_helo,
 				Timeout => 30) ) {
 	 $smtp->mail('');
 	 for(@addresses) {
